<%@ Page Language="C#" AutoEventWireup="true" Debug="true" ValidateRequest="false" %>

<%@ Import Namespace="System.IO" %>
<%@ Import Namespace="System.Xml" %>

<script runat="server">
	//This variable specifies relative path to the folder, where the gallery with uploaded files is located.
	//Do not forget about the slash in the end of the folder name.
	private string galleryPath = "../Gallery/";

	private void Page_Load(System.Object sender, System.EventArgs e)
	{
		//Get the source file and save it to disk. 

		//NOTE: Since each file is uploaded in a separate request (because 
		//FilesPerOnePackageCount param equals to 1), you should work only 
		//with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc). 
		HttpPostedFile sourceFile = Request.Files["SourceFile_1"];

		string fileName = GetSafeFileName(sourceFile.FileName);
		sourceFile.SaveAs(Server.MapPath(galleryPath + fileName));

		//Get the thumbnail and save it to disk.
		Request.Files["Thumbnail1_1"].SaveAs(Server.MapPath(galleryPath + "Thumbnails/" + fileName + ".jpg"));

		//Get file info and save it to XML file.
		//NOTE: In this demo this file is used by different upload threads asynchronously. That's why 
		//it is necessary to synchronize access to this file. 
		lock (Application) //TODO: Use synchronization in more narrow scope
		{
			string descriptionsPath = Server.MapPath(galleryPath + "Descriptions.xml");

			//Create XML file which will keep information about files (image dimensions, description, etc). 
			//XML is used solely for brevity. In real-life application most likely you will use database instead.
			XmlDocument descriptions = new XmlDocument();
			if (File.Exists(descriptionsPath))
			{
				descriptions.Load(descriptionsPath);
			}
			else
			{
				descriptions.AppendChild(descriptions.CreateElement("files"));
			}

			XmlElement xmlFile = descriptions.CreateElement("file");
			xmlFile.SetAttribute("name", fileName);
			xmlFile.SetAttribute("width", Request.Form["Width_1"]);
			xmlFile.SetAttribute("height", Request.Form["Height_1"]);
			xmlFile.SetAttribute("handlerUrl", Request.Url.PathAndQuery);

			descriptions.DocumentElement.AppendChild(xmlFile);

			descriptions.Save(descriptionsPath);
		}
	}

	//This method verifies whether file with such name already exists 
	//and if so, construct safe filename name (to avoid collision).
	private string GetSafeFileName(string fileName)
	{
		string newFileName = fileName;
		int j = 1;
		while (File.Exists(Server.MapPath(galleryPath + newFileName)))
		{
			newFileName = j + "_" + fileName;
			j++;
		}
		return newFileName;
	}
</script>

