<%@ Page Language="VB" AutoEventWireup="false" Debug="true" ValidateRequest="false" %>

<%@ Import Namespace="System.IO" %>
<%@ Import Namespace="System.Xml" %>
<%@ Import Namespace="System.Security.Cryptography" %>

<script runat="server">
	'This variable specifies relative path to the folder, where the gallery with uploaded files is located.
	'Do not forget about the slash in the end of the folder name.
	Private galleryPath As String = "../Gallery/"

	Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

		'Get the source file. 
		'NOTE: Since each file is uploaded in a separate request (because 
		'FilesPerOnePackageCount param equals to 1), you should work only 
		'with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc).       
		Dim sourceFile As HttpPostedFile = Request.Files("SourceFile_1")
		
		'Verify upload integrity. To do it, get the source file, compute hash value for it,
		'and compare the result with the hash value calculated by Image Uploader. 
        
		'NOTE: In real-life application a single hash method is typically enough.

		Dim sourceFileBytes As Byte()
		ReDim sourceFileBytes(sourceFile.InputStream.Length - 1)
		sourceFile.InputStream.Read(sourceFileBytes, 0, sourceFile.InputStream.Length)

		'Get SHA1 Hash.
		Dim postedSHA1Hash As String = Request.Form("HashCodeSHA_1")
		
		'Check if this value is actually uploaded.
		If Not (postedSHA1Hash Is Nothing) Then

			'Compute SHA1 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
			'the result should be also encoded with Base 64.
			Dim SHA1 As New SHA1CryptoServiceProvider()
			Dim actualSHA1Hash As String = Convert.ToBase64String(SHA1.ComputeHash(sourceFileBytes))

			'If the result differs from the uploaded one, the upload should be interpreted as corrupted.
			If (postedSHA1Hash <> actualSHA1Hash) Then
				Response.StatusCode = 400
				Response.End()
				Return
			End If
			
		End If
		
		'Get MD5 hash.
		Dim postedMD5Hash As String = Request.Form("HashCodeMD5_1")

		'Check if this value is actually uploaded.
		If Not (postedMD5Hash Is Nothing) Then

			'Compute MD5 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
			'the result should be also encoded with Base 64.
			Dim MD5 As New MD5CryptoServiceProvider()
			Dim actualMD5Hash As String = Convert.ToBase64String(MD5.ComputeHash(sourceFileBytes))

			'If the result differs from the uploaded one, the upload should be interpreted as corrupted.
			If (postedMD5Hash <> actualMD5Hash) Then
				Response.StatusCode = 400
				Response.End()
				Return
			End If
		
		End If

		'Get MD2 hash
		
		'NOTE: MD2 support is not available in standard .NET Framework libraries, so you will have 
		'to use some third party classes to use it. For example you can use the Mono.Security.dll
		'assembly from Mono project (http://www.mono-project.com) which includes the MD2Managed class.
		'Download this assembly and uncomment the code below: 

		'Dim postedMD2Hash As String = Request.Form("HashCodeMD2_1")

		'If Not (postedMD2Hash Is Nothing) Then
		
		'	'Compute MD2 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
		'	'the result should be also encoded with Base 64.			
		'	Dim MD2 As New Mono.Security.Cryptography.MD2Managed()
		'	Dim actualMD2Hash As String = Convert.ToBase64String(MD2.ComputeHash(sourceFileBytes))

		'	'If the result differs from the uploaded one, the upload should be interpreted as corrupted.			
		'	If postedMD2Hash <> actualMD2Hash Then
		'		Response.StatusCode = 400
		'		Response.End()
		'		Return
		'	End If
			
		'End If
		
		'If we reach this line, it means that file was not corrupted during upload. 
		'In this case we should save it to disk. 

		'Before saving uploaded files let's delete previously uploaded items. 
		
		'In this code sample each file is uploaded with a separate request. It means that this 
		'page will be called for each file individually (rather than once for all files). Therefore
		'we need a way to determine whether this page is called for new upload session or not.
		
		'To do it we check a PackageIndex POST field which returns a number of the request in the upload session.
		'If it is the very first package we should delete all files we uploaded before. 
		'Otherwise, previously uploaded files belong to the same upload session and we should not delete them. 	        
		Dim packageIndex As Integer = Int32.Parse(Request.Form("PackageIndex"))

		If packageIndex = 0 Then
			'Delete source files.
			Dim dir As New DirectoryInfo(Server.MapPath(galleryPath))
			For Each file As FileInfo In dir.GetFiles()
				file.Delete()
			Next
		End If

		'NOTE: If you do not want to delete previously uploaded files, just 
		'remove or comment out the code above.

		'Save the uploaded file to disk.
		Dim fileName As String = GetSafeFileName(sourceFile.FileName)
		sourceFile.SaveAs(Server.MapPath(galleryPath & fileName))
	End Sub

	'This method verifies whether file with such name already exists 
	'and if so, construct safe filename name (to avoid collision).	
	Private Function GetSafeFileName(ByVal fileName As String) As String
		
		Dim newFileName As String = fileName
		Dim j As Integer = 1
		While (File.Exists(Server.MapPath(galleryPath & newFileName)))
			newFileName = j & "_" & fileName
			j += 1
		End While
		
		Return newFileName
	
	End Function
</script>

