<%@ Page Language="VB" AutoEventWireup="false" %>

<%@ Import Namespace="System.IO" %>
<%@ Import Namespace="System.Xml" %>

<script runat="server">
	'This variable specifies relative path to the folder, where the gallery with uploaded files is located.
	'Do not forget about the slash in the end of the folder name.
	Private galleryPath As String = "../Gallery/"

	Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

		'First of all, clear data uploaded at previous time.

		'Delete source files.
		Dim dir As New DirectoryInfo(Server.MapPath(galleryPath))
		For Each file As FileInfo In dir.GetFiles()
			file.Delete()
		Next

		'Delete thumbnails.
		dir = New DirectoryInfo(Server.MapPath(galleryPath) & "/Thumbnails")
		For Each file As FileInfo In dir.GetFiles()
			file.Delete()
		Next
        
		'NOTE: If you do not want to delete previously uploaded files, just 
		'remove or comment out the code above.

		'Create XML file which will keep information about files (image dimensions, description, etc). 
		'XML is used solely for brevity. In real-life application most likely you will use database instead.
		Dim descriptions As New XmlDocument()
		descriptions.AppendChild(descriptions.CreateElement("files"))

		'Get total number of uploaded files (all files are uploaded in a single package).
		Dim fileCount As Integer = Int32.Parse(Request.Form("FileCount"))

		'Iterate through uploaded data and save the original file, thumbnail, and description.
		For i As Integer = 1 To fileCount

			'Get source file and save it to disk.
			Dim sourceFile As HttpPostedFile = Request.Files("SourceFile_" & i)
			Dim fileName As String = GetSafeFileName(Path.GetFileName(sourceFile.FileName))

			'In this demo the following imaging operations are applied:
			'  
			'  - If the user rotates the image in Image Uploader, rotate the original file.
			'  - Add a border around the image.
			Dim sourceBitmap As New System.Drawing.Bitmap(sourceFile.InputStream)
			Try
				
				'Check if user rotated the image and if yes, what is the angle.
				Dim angle As Integer = Int32.Parse(Request.Form("Angle_" & i))
				Select Case angle
					Case 90
						sourceBitmap.RotateFlip(System.Drawing.RotateFlipType.Rotate90FlipNone)
					Case 180
						sourceBitmap.RotateFlip(System.Drawing.RotateFlipType.Rotate180FlipNone)
					Case 270
						sourceBitmap.RotateFlip(System.Drawing.RotateFlipType.Rotate270FlipNone)
				End Select

				'Add extra pixels to the image to be able to draw a border.
				Dim resultBitmap As New System.Drawing.Bitmap(sourceBitmap.Width + 30, sourceBitmap.Height + 30)
				Try
					
					Dim graphics As System.Drawing.Graphics = System.Drawing.Graphics.FromImage(resultBitmap)
					Try
						
						'Fill the image with the border color.
						graphics.FillRectangle(New System.Drawing.SolidBrush(System.Drawing.Color.FromArgb(255, 240, 240, 240)), _
						 0, 0, sourceBitmap.Width + 30, sourceBitmap.Height + 30)

						'Copy the original image to the center of new image.
						graphics.DrawImage(sourceBitmap, 15, 15, sourceBitmap.Width, sourceBitmap.Height)

						'Draw double border.
						Dim pen As New System.Drawing.Pen(System.Drawing.Color.Black, 1)

						graphics.DrawRectangle(pen, 13, 13, sourceBitmap.Width + 3, sourceBitmap.Height + 3)
						graphics.DrawRectangle(pen, 10, 10, sourceBitmap.Width + 9, sourceBitmap.Height + 9)

						'Save the result file to disk.
						resultBitmap.Save(Server.MapPath(galleryPath & fileName))

					Finally
						graphics.Dispose()
					End Try
					
				Finally
					resultBitmap.Dispose()
				End Try
				
			Finally
				sourceBitmap.Dispose()
			End Try
				
			'Get first thumbnail (the single thumbnail in this code sample) and save it to disk. 
			'NOTE: No imaging operations are applied on the thumbnail. But if you need it, feel 
			'free to modify this code.
			Dim ThumbnailFile As HttpPostedFile = Request.Files("Thumbnail1_" & i)
			ThumbnailFile.SaveAs(Server.MapPath(galleryPath & "Thumbnails/" & fileName & ".jpg"))

			'Save file info.
			Dim file As XmlElement = descriptions.CreateElement("file")
			file.SetAttribute("name", fileName)
			file.SetAttribute("width", Request.Form("Width_" & i))
			file.SetAttribute("height", Request.Form("Height_" & i))
			file.SetAttribute("description", Request.Form("Description_" & i))

			descriptions.DocumentElement.AppendChild(file)
		Next

		descriptions.Save(Server.MapPath(galleryPath & "Descriptions.xml"))
	End Sub

	'This method verifies whether file with such name already exists 
	'and if so, construct safe filename name (to avoid collision).	
	Private Function GetSafeFileName(ByVal fileName As String) As String
		
		Dim newFileName As String = fileName
		Dim j As Integer = 1
		While (File.Exists(Server.MapPath(galleryPath & newFileName)))
			newFileName = j & "_" & fileName
			j += 1
		End While
		
		Return newFileName
	
	End Function
</script>

