<%@ page language='java' import='java.io.*,java.util.*,javax.servlet.*,javax.servlet.http.*,org.apache.commons.fileupload.*,org.w3c.dom.*,org.w3c.dom.ls.*,java.awt.Color,java.awt.Graphics2D,java.awt.geom.*,java.awt.image.*,com.sun.image.codec.jpeg.*'%>
<%!
//This variable specifies relative path to the folder, where the gallery with uploaded files is located.
//Do not forget about the slash in the end of the folder name.
String galleryPath = "/Gallery/";

String absGalleryPath;
String absThumbnailsPath;
String absTempPath;

//This method verifies whether file with such name already exists
//and if so, construct safe filename name (to avoid collision).
String getSafeFileName(String fileName) {
    String newFileName = fileName;
    File file = new File(absGalleryPath + File.separator + newFileName);
    int j = 1;
    while (file.exists()) {
	newFileName = j + "_" + fileName;
	file = new File(absGalleryPath + File.separator + newFileName);
	j = j + 1;
    }
    return newFileName;
}

private void deleteFiles(String path) {
    File dir = new File(path);

    String[] dirList = dir.list();
    for (int i = 0; i < dirList.length; i++) {
	File file = new File(path + File.separator + dirList[i]);
	if (file.isFile()) {
	    file.delete();
	}
    }
}

private void saveXml(Document document, String path) throws IOException {
    DOMImplementation implementation = document.getImplementation();
    DOMImplementationLS implementationLS = (DOMImplementationLS) implementation.getFeature("LS", "3.0");
    LSSerializer serializer = implementationLS.createLSSerializer();
    LSOutput output = implementationLS.createLSOutput();
    FileOutputStream stream = new FileOutputStream(path);
    output.setByteStream(stream);
    serializer.write(document, output);
    stream.close();
}
%>
<%
//Process request.
ServletContext context = getServletContext();
absGalleryPath = context.getRealPath(galleryPath);
absThumbnailsPath = context.getRealPath(galleryPath + "/Thumbnails");
absTempPath = context.getRealPath(galleryPath + "/Temp");

//First of all, clear files and data uploaded at previous time.

//Delete source files.
deleteFiles(absGalleryPath);

//Delete thumbnails.
deleteFiles(absThumbnailsPath);

//NOTE: If you do not want to delete previously uploaded files, just
//remove or comment out the code above.

//Process upload.
DiskFileUpload fu = new DiskFileUpload();
//Set maximum size before a FileUploadException will be thrown.
fu.setSizeMax(100000000);
//Set maximum size that will be stored in memory.
fu.setSizeThreshold(4096);
//Set the location for saving data that is larger than getSizeThreshold().
fu.setRepositoryPath(absTempPath);

//Get uploaded files.
List listFileItems = fu.parseRequest(request);

//Put them in hash table for fast access.
Hashtable fileItems = new Hashtable();

for (int i = 0; i < listFileItems.size(); i++) {
    FileItem fileItem = (FileItem)(listFileItems.get(i));
    fileItems.put(fileItem.getFieldName(), fileItem);
}

//Create XML file which will keep information about files (image dimensions, description, etc).
//XML is used solely for brevity. In real-life application most likely you will use database instead.
javax.xml.parsers.DocumentBuilder builder =
	javax.xml.parsers.DocumentBuilderFactory.newInstance().newDocumentBuilder();
org.w3c.dom.Document descriptions = builder.newDocument();
descriptions.appendChild(descriptions.createElement("files"));

//Get total number of uploaded files (all files are uploaded in a single package).
int fileCount = Integer.parseInt(((FileItem) fileItems.get("FileCount")).getString());

//Iterate through uploaded data and save the original file, thumbnail, and description.
for (int i = 1; i <= fileCount; i++) {
    //Get source file and save it to disk.
    FileItem sourceFileItem = (FileItem) fileItems.get("SourceFile_" + Integer.toString(i));
    String fileName = getSafeFileName(new File(sourceFileItem.getName()).getName());
    File sourceFile = new File(absGalleryPath + File.separator + fileName);
    sourceFileItem.write(sourceFile);
    
    //In this demo the following imaging operations are applied:
    //  
    //  - If the user rotates the image in Image Uploader, rotate the original file.
    //  - Add a border around the image.
    FileInputStream sourceFileInput = new FileInputStream(sourceFile);
    JPEGImageDecoder jpegDec = JPEGCodec.createJPEGDecoder(sourceFileInput);
    BufferedImage sourceImage = jpegDec.decodeAsBufferedImage();
    sourceFileInput.close();    
    
    //Check if user rotated the image and if yes, what is the angle.
    int angle = Integer.parseInt(((FileItem) fileItems.get("Angle_" + i)).getString());    
    
    BufferedImage resultImage;

    //Create rotated image with extra pixels to be able to draw a border.    
    if (angle == 90 || angle == 270 ) {
	resultImage = new BufferedImage(sourceImage.getHeight() + 30, sourceImage.getWidth() + 30, BufferedImage.TYPE_INT_RGB);    
    } else {
	resultImage = new BufferedImage(sourceImage.getWidth() + 30, sourceImage.getHeight() + 30, BufferedImage.TYPE_INT_RGB);    
    }
    
    Graphics2D graphics = resultImage.createGraphics();    
    
    //Fill the image with the border color.
    graphics.setColor(Color.LIGHT_GRAY);
    graphics.fillRect(0, 0, resultImage.getWidth(), resultImage.getHeight());
    
    //Draw double border.
    graphics.setColor(Color.BLACK);
    graphics.drawRect(13, 13, resultImage.getWidth() - 26, resultImage.getHeight() - 26);
    graphics.drawRect(10, 10, resultImage.getWidth() - 20, resultImage.getHeight() - 20);    
        
    //Copy the original image to the center of new image.    
    AffineTransform rotation = new AffineTransform();
    switch (angle){
	case 0:
	    graphics.drawImage( sourceImage, null, (resultImage.getWidth() - sourceImage.getWidth()) / 2, 
		    (resultImage.getHeight() - sourceImage.getHeight()) / 2);    
	    break;
	case 90:
	    rotation.rotate(Math.PI / 2, resultImage.getWidth() / 2, resultImage.getHeight() / 2);
	    graphics.transform(rotation);
	    graphics.drawImage( sourceImage, null, (resultImage.getWidth() - sourceImage.getWidth()) / 2, 
		    (resultImage.getHeight() - sourceImage.getHeight())  /  2);
	    break;
	case 180:
	    rotation.rotate(Math.PI, resultImage.getWidth() / 2, resultImage.getHeight() / 2);
	    graphics.transform(rotation);
	    graphics.drawImage( sourceImage, null, (resultImage.getWidth() - sourceImage.getWidth()) / 2, 
		    (resultImage.getHeight() - sourceImage.getHeight()) / 2);    
	    break;
	case 270:
	    rotation.rotate(Math.PI / -2, resultImage.getWidth() / 2, resultImage.getHeight() / 2);
	    graphics.transform(rotation);
	    graphics.drawImage(sourceImage, null, (resultImage.getWidth() - sourceImage.getWidth()) / 2, 
		    (resultImage.getHeight() - sourceImage.getHeight()) / 2);
	    break;
    }
    
    graphics.dispose();
    
    //Save the result file to disk.
    java.io.FileOutputStream sourceFileOutput = new java.io.FileOutputStream(sourceFile);
    com.sun.image.codec.jpeg.JPEGImageEncoder jpegEnc = com.sun.image.codec.jpeg.JPEGCodec.createJPEGEncoder(sourceFileOutput);
    jpegEnc.encode(resultImage);
    sourceFileOutput.close();    


    //Get first thumbnail (the single thumbnail in this code sample) and save it to disk.
    FileItem thumbnail1FileItem = (FileItem) fileItems.get("Thumbnail1_" + Integer.toString(i));
    File thumbnail1File = new File(absThumbnailsPath + File.separator + fileName + ".jpg");
    thumbnail1FileItem.write(thumbnail1File);
    
    //Save file info.
    Element xmlFile = descriptions.createElement("file");
    xmlFile.setAttribute("name", fileName);
    xmlFile.setAttribute("width", ((FileItem) fileItems.get("Width_" + i)).getString());
    xmlFile.setAttribute("height", ((FileItem) fileItems.get("Height_" + i)).getString());
    xmlFile.setAttribute("description", ((FileItem) fileItems.get("Description_" + i)).getString());
    descriptions.getDocumentElement().appendChild(xmlFile);
}

saveXml(descriptions, absGalleryPath + File.separator + "Descriptions.xml");
%>
