<?php
//This variable specifies relative path to the folder, where the gallery with uploaded files is located.
//Do not forget about the slash in the end of the folder name.
$galleryPath = "../Gallery/";

$absGalleryPath = realpath($galleryPath) . "/";
$absThumbnailsPath = realpath($galleryPath . "Thumbnails/") . "/";

function saveUploadedFiles()
{
	global $absGalleryPath, $absThumbnailsPath;
	
	//First of all, clear data uploaded at previous time.

	//In this code sample each file is uploaded with a separate request. It means that this 
	//page will be called for each file individually (rather than once for all files). Therefore
	//we need a way to determine whether this page is called for new upload session or not.
	//
	//To do it we check a PackageIndex POST field which returns a number of the request in the upload session.
	//If it is the very first package we should delete all files and thumbnails we uploaded before. 
	//Otherwise, previously uploaded files belong to the same upload session and we should not delete them. 	
	$packageIndex = $_POST ["PackageIndex"];

	//If we receive the first file, we delete all files and thumbnails we uploaded before.  	
	if ($packageIndex == 0)
	{
		//Delete source files.
		$handle = opendir($absGalleryPath);
	
		while (false !== ($file = readdir($handle)))
		{
			if (is_file($absGalleryPath . $file))
			{
				unlink($absGalleryPath . $file);
			}
		}
		closedir($handle); 
	
		//Delete thumbnails
		$handle = opendir($absThumbnailsPath);	
		while (false !== ($file = readdir($handle))) 
		{
			if (is_file($absThumbnailsPath . $file))
			{
				unlink($absThumbnailsPath . $file);
			}
		}
		closedir($handle);
	}

	//NOTE: If you do not want to delete previously uploaded files, just 
	//remove or comment out the code above.

	//Create XML file which will keep information about files (image dimensions, description, etc). 
	//XML is used solely for brevity. In real-life application most likely you will use database instead.
	$descriptions = new DOMDocument('1.0');

	//If we receive the first file then 
	//we start from empty file with descriptions
	if ($packageIndex == 0)
	{
		$descriptions->appendChild($descriptions->createElement("files"));
	}
	else
	{
		$descriptions->load($absGalleryPath . "Descriptions.xml");
	}
    
	//NOTE: Since each file is uploaded in a separate request (because 
	//FilesPerOnePackageCount param equals to 1), you should work only 
	//with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc). 
	if (!$_FILES["SourceFile_1"]['size'])
	{
		return;	
	}
	$fileName = getSafeFileName($_FILES["SourceFile_1"]['name']);
	move_uploaded_file($_FILES["SourceFile_1"]['tmp_name'], $absGalleryPath . "/" . $fileName);
    
	//Get the thumbnail and save it to disk.
	if (!$_FILES["Thumbnail1_1"]['size'])
	{
		return;	
	}
	move_uploaded_file($_FILES["Thumbnail1_1"]['tmp_name'], $absGalleryPath . "/Thumbnails/" . $fileName . ".jpg");

	//Save file info.
	$xmlFile = $descriptions->createElement("file");
	$xmlFile->setAttribute("name", $fileName);
	$xmlFile->setAttribute("width", $_POST ['Width_1']);
	$xmlFile->setAttribute("height", $_POST ['Height_1']);
	$xmlFile->setAttribute("description", $_POST ['Description_1']);
	$descriptions->documentElement->appendChild($xmlFile);	

	$descriptions->save($absGalleryPath . "Descriptions.xml");
}

//This method verifies whether file with such name already exists 
//and if so, construct safe filename name (to avoid collision).	
function getSafeFileName($fileName)
{
	global $absGalleryPath;
	
	$newFileName = $fileName;
	$j = 1;
	while (file_exists($absGalleryPath . "/" . $newFileName))
	{
		$newFileName = $j . "_" . $fileName;
		$j = $j + 1;
	}
	return $newFileName;	
}

saveUploadedFiles();
?>

