<?php
//This variable specifies relative path to the folder, where the gallery with uploaded files is located.
//Do not forget about the slash in the end of the folder name.
$galleryPath = "../Gallery/";

$absGalleryPath = realpath($galleryPath) . "/";
$absThumbnailsPath = realpath($galleryPath . "Thumbnails/") . "/";

function saveUploadedFiles()
{
	global $absGalleryPath, $absThumbnailsPath;
	
	//First of all, clear files and data uploaded at previous time.
	
	//Delete source files.
	$handle = opendir($absGalleryPath);

	while (false !== ($file = readdir($handle)))
	{
		if (is_file($absGalleryPath . $file))
		{
			unlink($absGalleryPath . $file);
		}
	}
	closedir($handle); 

	//Delete thumbnails
	$handle = opendir($absThumbnailsPath);	
	while (false !== ($file = readdir($handle))) 
	{
		if (is_file($absThumbnailsPath . $file))
		{
			unlink($absThumbnailsPath . $file);
		}
	}
	closedir($handle);

	//NOTE: If you do not want to delete previously uploaded files, just 
	//remove or comment out the code above.
	
	//Create XML file which will keep information about files (image dimensions, description, etc). 
	//XML is used solely for brevity. In real-life application most likely you will use database instead.
	$descriptions = new DOMDocument('1.0');
	$descriptions->appendChild($descriptions->createElement("files"));
	
	//Get total number of uploaded files (all files are uploaded in a single package).
	$fileCount = $_POST ["FileCount"];
	
	//Iterate through uploaded data and save the original file, thumbnail, and description.
	for ($i = 1; $i <= $fileCount; $i++)
	{
		//Get source file and save it to disk.
		$sourceFileField = "SourceFile_" . $i;
		if (!$_FILES[$sourceFileField]['size'] || !is_uploaded_file($_FILES[$sourceFileField]['tmp_name']))
		{
			return;	
		}

		$fileName = getSafeFileName($_FILES[$sourceFileField]['name']);

		//In this demo the following imaging operations are applied:
		//  
		//  - If the user rotates the image in Image Uploader, rotate the original file.
		//  - Add a border around the image.		
		$sourceImage = imagecreatefromjpeg($_FILES[$sourceFileField]['tmp_name']);
		//Check if user rotated the image and if yes, what is the angle.
		$angle = intval($_POST ["Angle_" . $i]);
		switch ($angle) {
		case 90:
			#Image Uploader uses clockwise angle, at that time as
			#imagerotate function accepts counterclockwise one	
			$sourceImage = imagerotate($sourceImage, 270, 0);
			break;
		case 180:
			$sourceImage = imagerotate($sourceImage, 180, 0);
		break;
		case 270:
			#Image Uploader uses clockwise angle, at that time as
			#imagerotate function accepts counterclockwise one		
			$sourceImage = imagerotate($sourceImage, 90, 0);
			break;
		}

		$width = imagesx($sourceImage);
		$height = imagesy($sourceImage);			
		//Add extra pixels to the image to be able to draw a border.			
		$resultImage = imagecreatetruecolor($width + 30, $height + 30);
		//Fill the image with the border color.		
		imagefilledrectangle($resultImage, 0, 0, $width + 30, $height + 30, 0xE0E0E0);
		//Copy the original image to the center of new image.
		imagecopy ($resultImage, $sourceImage, 15, 15, 0, 0, $width, $height);
		//Draw double border.
		imagerectangle($resultImage, 13, 13, $width + 16, $height + 16, 0x000000);
		imagerectangle($resultImage, 10, 10, $width + 19, $height + 19, 0x000000);
		//Save the result file to disk.
		imagejpeg($resultImage, $absGalleryPath . "/" . $fileName);
		
		//Get first thumbnail (the single thumbnail in this code sample) and save it to disk. 
		//NOTE: No imaging operations are applied on the thumbnail. But if you need it, feel 
		//free to modify this code.
		$thumbnail1Field = "Thumbnail1_" . $i;
		if (!$_FILES[$thumbnail1Field]['size'])
		{
			return;	
		}
		move_uploaded_file($_FILES[$thumbnail1Field]['tmp_name'], $absGalleryPath . "/Thumbnails/" . $fileName . ".jpg");

		//Save file info.
		$xmlFile = $descriptions->createElement("file");
		$xmlFile->setAttribute("name", $fileName);
		$xmlFile->setAttribute("width", $_POST ['Width_' . $i]);
		$xmlFile->setAttribute("height", $_POST ['Height_' . $i]);
		$xmlFile->setAttribute("description", $_POST ['Description_' . $i]);
		$descriptions->documentElement->appendChild($xmlFile);
	}

	$descriptions->save($absGalleryPath . "Descriptions.xml");
}

//This method verifies whether file with such name already exists 
//and if so, construct safe filename name (to avoid collision).	
function getSafeFileName($fileName)
{
	global $absGalleryPath;
	
	$newFileName = $fileName;
	$j = 1;
	while (file_exists($absGalleryPath . "/" . $newFileName))
	{
		$newFileName = $j . "_" . $fileName;
		$j = $j + 1;
	}
	return $newFileName;	
}

saveUploadedFiles();
?>

