require 'cgi'
require 'rexml/document'


#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
$galleryPath = "../Gallery/"

def print_html()
	print "Content-Type: text/html\r\n\r\n"
	print "\r\n"
end

def save_uploaded_files()
	$absGalleryPath = File.expand_path($galleryPath)
	absThumbnailsPath = File.join($absGalleryPath, "Thumbnails")

	cgi = CGI.new()

	#First of all, clear data uploaded at previous time.

	#In this code sample each file is uploaded with a separate request. It means that this 
	#page will be called for each file individually (rather than once for all files). Therefore
	#we need a way to determine whether this page is called for new upload session or not.

	#To do it we check a PackageIndex POST field which returns a number of the request in the upload session.
	#If it is the very first package we should delete all files and thumbnails we uploaded before. 
	#Otherwise, previously uploaded files belong to the same upload session and we should not delete them. 	
	packageIndex = Integer(cgi.params['PackageIndex'].first.read)

	#If we receive the first file, we delete all files and thumbnails we uploaded before.  	
	if packageIndex == 0
		#Delete source files.		
		Dir.foreach($absGalleryPath) {|fileName|
			filePath = File.join($absGalleryPath, fileName)
			if File.ftype(filePath) == "file" then
				File.delete(filePath)
			end
		}

		#Delete thumbnails
		Dir.foreach(absThumbnailsPath) {|fileName|
			filePath = File.join(absThumbnailsPath, fileName)
			if File.ftype(filePath) == "file" then
				File.delete(filePath)
			end
		}
	end

	#NOTE: If you do not want to delete previously uploaded files, just 
	#remove or comment out the code above.

	#Create XML file which will keep information about files (image dimensions, description, etc). 
	#XML is used solely for brevity. In real-life application most likely you will use database instead.

	descriptionsPath = File.join($absGalleryPath, "Descriptions.xml")

	#If we receive the first file then 
	#we start from empty file with descriptions
	if packageIndex == 0 then
		descriptions = REXML::Document.new 
		filesElem = descriptions.add_element("files")
	else
		file = File.new(descriptionsPath)
		descriptions = REXML::Document.new file
		file.close
		filesElem = REXML::XPath.first(descriptions, "/files")
	end

	#NOTE: Since each file is uploaded in a separate request (because 
	#FilesPerOnePackageCount param equals to 1), you should work only 
	#with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc). 
	sourceFile = cgi.params["SourceFile_1"].first
	fileName = get_safe_file_name(sourceFile.original_filename)
	sourceFileTargetPath = File.join($absGalleryPath, fileName)
	File.open(sourceFileTargetPath.untaint, 'wb') { |file| file << sourceFile.read}

	#Get the thumbnail and save it to disk.
	thumbnail1 = cgi.params["Thumbnail1_1"].first
	thumbnail1TargetPath = File.join(absThumbnailsPath, fileName)
	File.open(thumbnail1TargetPath.untaint, 'wb') { |file| file << thumbnail1.read}

	#Save file info.
	fileElem = filesElem.add_element "file"
	fileElem.attributes["name"] = fileName
	fileElem.attributes["width"] = cgi.params["Width_1"].first.read
	fileElem.attributes["height"] = cgi.params["Height_1"].first.read
	fileElem.attributes["description"] = cgi.params["Description_1"].first.read

	File.open(descriptionsPath.untaint, 'w') { |file| descriptions.write file}
end

def get_safe_file_name(fileName)
	newFileName = File.basename(fileName)
	j = 1
	while FileTest.exist?(File.join($absGalleryPath, newFileName))
		newFileName = j.to_s + "_" + fileName
	end
	return newFileName
end

print_html()

save_uploaded_files()